@@ -300,6 +300,28 @@ function display_result(&$tag) {
     }
     $tag["<<LDAPFILTER>>"] = $ldapfilter;
 
+    /* ĥDB/ѥ */
+    $html_extension = "";
+    foreach ($db_types as $e_type) {
+        $e_file = "";
+        $type = "";
+        if (isset($samma_conf["extensiondb"]) === TRUE &&
+            $samma_conf["extensiondb"] != "") {
+            $extension = explode(":", $samma_conf["extensiondb"], 2);
+            $type = $extension[0];
+            $e_file = escape_html($extension[1]);
+        }
+        $selected = "";
+        /* פ */
+        if ($e_type == $type) {
+            $selected = "selected";
+        }
+        $html_extension .= "<option value=\"$e_type\" $selected>$e_type";
+        $tag["<<HTML_EXTENSION>>"] = $html_extension;
+
+    }
+    $tag["<<E_FILE>>"] = $e_file;
+
     return TRUE;
 }
 
@@ -320,6 +342,7 @@ function check_conf_data(&$data)
     global $err_msg;
     global $logfacility;
     global $str_code;
+    global $samma_conf;
 
     /* Ϣѥѥ */
     /* å */
@@ -582,6 +605,24 @@ function check_conf_data(&$data)
         }
     }
 
+    /* ĥDB/ѥ */
+    /* å */
+    if ($data["ex_dbfile"] == "") {
+        $data["extensiondb"] = "";
+    } else {
+        /* db̾å(".db"ĤƤ뤫) */
+        if (substr($data["ex_dbfile"], -3, 3) != ".db") {
+            $data["ex_dbfile"] .= ".db";
+            $data["extensiondb"] .= ".db";
+        }
+
+        /* å(ʤк) */
+        if (check_db($data["ex_dbfile"], $data["ex_dbtype"]) === FALSE) {
+            $err_msg = "ĥ" . $err_msg;
+            return FALSE;
+        }
+    }
+
     return TRUE;
 
 }
@@ -730,6 +771,13 @@ function set_disp_data($data, &$disp_data)
         $disp_data["rcptdb"] = $data["rp_dbtype"] . ":" . $data["rp_dbfile"];
     }
 
+    /* extensiondb */
+    if (isset($data["ex_dbfile"]) === TRUE) {
+        $disp_data["ex_dbfile"] = $data["ex_dbfile"];
+        $disp_data["ex_dbtype"] = $data["ex_dbtype"];
+        $disp_data["extensiondb"] = $data["ex_dbtype"] . ":" . $data["ex_dbfile"];
+    }
+
     /* templatepath */
     if (isset($data["templatepath"]) === TRUE) {
         $disp_data["templatepath"] = $data["templatepath"];
@@ -920,6 +968,7 @@ if (isset($_POST["mod"]) === TRUE) {
 /***********************************************************
  * ɽ
  **********************************************************/
+
 /* ̤Υ */
 set_tag_common($tag);
 
